:orphan:

.. include:: _contributors.rst
.. currentmodule:: treeple

.. _current:

Version 0.9
===========

**In Development**

This release include a rename of the package to from ``scikit-learn`` to ``treeple``
The users can replace the previous usage as follows:
``import sktree`` to ``import treeple``
``from sktree import tree`` to ``from treeple import tree``
``from sktree import ...`` to ``from treeple import ...``


Changelog
---------

- |API| Rename the package to ``treeple``. By `SUKI-O`_ (:pr:`#292`)


Code and Documentation Contributors
-----------------------------------

Thanks to everyone who has contributed to the maintenance and improvement of
the project since version inception, including:

* `Adam Li`_
* `SUKI-O`_
